package com.biganto.visual.roompark.conductor.dialogs.tour_chooser

import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.annotation.LayoutRes
import androidx.recyclerview.widget.DividerItemDecoration
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import butterknife.BindView
import com.biganto.visual.roompark.R
import com.biganto.visual.roompark.domain.model.TourModel
import com.biganto.visual.roompark.presentation.screen.settings.util.CommonRecyclerAdapter
import com.biganto.visual.roompark.presentation.screen.settings.util.CommonViewHolder
import com.bluelinelabs.conductor.Controller
import com.google.android.material.textview.MaterialTextView
import io.reactivex.disposables.CompositeDisposable
import timber.log.Timber


/**
 * Created by Vladislav Bogdashkin on 09.04.2019.
 */

internal const val  TOUR_MODEL_LIST = "CHOOSE_TOUR_LIST_KEY"

private fun formBundle(photos: ArrayList<TourModel>): Bundle {
    val b = Bundle()
    b.putParcelableArrayList(TOUR_MODEL_LIST,photos)
    return b
}

class ChooseTourDialogController : Controller {

    constructor(args: Bundle) : super(args)

    constructor(items: ArrayList<TourModel>) : super(formBundle(items))

    private lateinit var recyclerView : RecyclerView

    private val detachDisposable = CompositeDisposable()

    override fun onDetach(view: View) {
        detachDisposable.clear()
        super.onDetach(view)
    }

    override fun onCreateView(inflater: LayoutInflater, container: ViewGroup): View {
        val view = inflater.inflate(getLayoutId(), container, false)

        recyclerView = view.findViewById(R.id.toursList)
        recyclerView.layoutManager =
            LinearLayoutManager(activity, RecyclerView.VERTICAL, false)
        recyclerView.adapter = TourChooserAdapter()
        recyclerView.itemAnimator = null
        recyclerView.addItemDecoration(
            DividerItemDecoration(activity,DividerItemDecoration.VERTICAL)
        )

        args.getParcelableArrayList<TourModel>(TOUR_MODEL_LIST)?.let {
            (recyclerView.adapter as TourChooserAdapter).setItems(it)
        }

        detachDisposable.add(
        (recyclerView.adapter as TourChooserAdapter).onItemClicked.subscribe {
            Timber.d("gonna shit : $it")
//            router.replaceTopController(RouterTransaction.with(
//                PhotoDialogController(
//                    it.url
//                )
//            )
//                .popChangeHandler(DialogChangeHandler())
//                .pushChangeHandler(DialogChangeHandler())
//            )
        })

        view.findViewById<View>(R.id.cancel_button).setOnClickListener { handleBack() }

        return view
    }

    @LayoutRes
    fun getLayoutId() = R.layout.tours_chooser_screen

    override fun handleBack(): Boolean {
        return router.popCurrentController()
    }


}

internal class TourChooserAdapter:CommonRecyclerAdapter<TourChooserViewHolder,TourModel>(){
    override val vhKlazz = TourChooserViewHolder::class
    override fun getVhLayout(): Int = R.layout.tour_chooser_viewholder
}

internal class TourChooserViewHolder(itemView: View) :CommonViewHolder<TourModel>(itemView){

    @BindView(R.id.tour_name)
    lateinit var tourName : MaterialTextView

    override fun onViewBound(model: TourModel) {
        tourName.text = model.title
    }

}
